@@ -80,7 +80,7 @@ QAbstractFileEngine* RemoteFileEngineHandler::create(const QString &fileName) co
 class RemoteFileEngineIterator : public QAbstractFileEngineIterator
 {
 public:
-    RemoteFileEngineIterator(const QString &path, QDir::Filters filters, const QStringList &nameFilters,
+    RemoteFileEngineIterator(const QString &path, QDirListing::IteratorFlags filters, const QStringList &nameFilters,
             const QStringList &files)
 #if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
         : QAbstractFileEngineIterator(path, filters, nameFilters)
@@ -177,8 +177,7 @@ bool RemoteFileEngine::atEnd() const
 */
 #if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
 QAbstractFileEngine::IteratorUniquePtr
-RemoteFileEngine::beginEntryList(const QString &path, QDir::Filters filters,
-                                   const QStringList &filterNames)
+RemoteFileEngine::beginEntryList(const QString &path, QDirListing::IteratorFlags filters, const QStringList &filterNames)
 #else
 QAbstractFileEngine::Iterator* RemoteFileEngine::beginEntryList(QDir::Filters filters,
     const QStringList &filterNames)
@@ -252,6 +251,16 @@ QStringList RemoteFileEngine::entryList(QDir::Filters filters, const QStringList
     return m_fileEngine.entryList(filters, filterNames);
 }
 
+QStringList RemoteFileEngine::entryList(QDirListing::IteratorFlags filters, const QStringList &filterNames) const
+{
+    if ((const_cast<RemoteFileEngine *>(this))->connectToServer()) {
+        return callRemoteMethod<QStringList>
+            (QString::fromLatin1(Protocol::QAbstractFileEngineEntryList),
+            static_cast<qint32>(filters), filterNames);
+    }
+    return m_fileEngine.entryList(filters, filterNames);
+}
+
 /*!
 */
 QFile::FileError RemoteFileEngine::error() const
